# HyperCog CLI apps

This project has three command-line applications:

- [cement-cli](./cement-cli)
- [sidenor-cli](./sidenor-cli)
- [pubadmin-cli](./pubadmin-cli)

There is also a simulator to generate a bunch of transactions and affect stats.

- [@hypercog/batch-sim](./batch-sim)

Finally, there is a common library that they use:

- [@hypercog/utils](./utils)

## Configuration

To install the dependencies of all apps, simply run the following command in this directory.

```bash
npm i
```

## Usage

To use any of the applications, simply go to the subdirectory and run `node index.js`.
To learn how to use it, you can use its _help_ command (or the _-h_ param).

```bash
$ node index.js
Usage: index [options] [command]

Options:
  -V, --version            output the version number
  -a, --api <value>        API URL (env: API_URL)
  -n, --network <value>    Network the API should connect to (env: NETWORK)
  -c, --channel <value>    Channel name (env: CHANNEL_NAME)
  -h, --chaincode <value>  Chaincode name (env: CHAINCODE_NAME)
  -u, --user <value>       User who will operate with blockchain. E.g., user@organization.com (env: USER_ID)
  -p, --password <value>   Password for the user (env: PASSWORD)
  --help                   display help for command

Commands:
  register [options]       Initial registration of the slag
  composition [options]    Provide a slag composition measure
  to-cone [options]        Send slag to cone
  to-stock [options]       Send slag from cone to stock
  bid-accept [options]     Accept bid for slag stock
  bid-reject [options]     Reject bid for slag stock
  help [command]           display help for command
```

**Note 1**: Some parameters can be defined in environment variables.
You can also create a _.env_ file with these default parameters.

**Note 2**: Some optional parameters can also be introduced in a prompt after executing the command.

## Usage examples

```bash
$ cd sidenor-cli
$ node index.js register --asset-name "Slag 1"
Registered asset asst_07b75e28-6685-4e18-b810-75e410dd37f2

$ node index.js composition
? Select asset asst_a9e0bd5d-aaa2-412e-95ee-c7cff1f831dc (Slag 1, type: 10, status: slag)
? Choose the percentage of CaO content in the slag (min: 40%, max 70%): 43

$ node index.js to-cone
? Select asset asst_07b75e28-6685-4e18-b810-75e410dd37f2 (Slag 1, type: 10, status: slag)
Moved to cone c28bed645434c46376369bc5cc400b4c

$ node index.js register --asset-name "Slag 2"
Registered asset asst_c51fa4b7-078d-4880-bd16-79235c24830e

$ node index.js to-cone
? Select asset asst_c51fa4b7-078d-4880-bd16-79235c24830e (Slag 2, type: 10, status: slag)
Moved to cone 6007feb7e2984c92d8efc13c23606fbb

$ node index.js register --asset-name "Slag 3"
Registered asset asst_8e97b751-be1b-41c1-a425-67c49cdd8a33

$ node index.js to-cone
? Select asset asst_8e97b751-be1b-41c1-a425-67c49cdd8a33 (Slag 3, type: 10, status: slag)
Moved to cone 513be341a8c15c74dc06ca434b33cb36

$ node index.js to-stock
? Select asset 513be341a8c15c74dc06ca434b33cb36 (Slag batch (in cone), type: 1002, status: batched)
? Select the stock where the cone will be merged newStock (New stock, type: 10 02, status: stocked)
Moved to stock 6007feb7e2984c92d8efc13c23606fbb

$ cd ../cement-cli
$ node index.js bid
? Select asset 19e2f7a99288dfc9a2902e71bfc9dfe6 (Stock, type: 1002, status: stocked)
? Choose an amount of slag 34
? Provide the offered price 3
Bid for slag stock 19e2f7a99288dfc9a2902e71bfc9dfe6

$ cd ../sidenor-cli
$ node index.js bid-accept
? Select asset 19e2f7a99288dfc9a2902e71bfc9dfe6 (Stock, type: 1002, status: stocked)
? Select the bidder whose bid will be accepted cement-company1-com:eDUwOTo6Q049dXNlcixPVT1jbGllbnQrT1U9b3JnMStPVT1kZXBhcnRtZW50MTo6Q049Y2EuY2VtZW5
0LWNvbXBhbnkxLmNvbSxPPWNlbWVudC1jb21wYW55MS5jb20sTD1SYWxlaWdoLFNUPU5vcnRoIENhcm9saW5hLEM9VVM= (quantity: 34, price: 3)
Bid from cement-company1-com:eDUwOTo6Q049dXNlcixPVT1jbGllbnQrT1U9b3JnMStPVT1kZXBhcnRtZW50MTo6Q049Y2EuY2VtZW50LWNvbXBhbnkxLmNvbSxPPWNlbWVudC1jb21wYW55MS5jb20sTD1SYWxlaWdoLFNUPU5vcnRoIENhcm9saW5hLEM9VVM= accepted for asset 19e2f7a99288dfc9a2902e71bfc9dfe6

$ node index.js discard-stock
? Select asset 7bbed24d305800c2f2e61b7f14539249 (Stock, type: 1002, status: stocked)
? Choose an amount of slag (max: 7297 kg): 729
Discarded stock 15fb63d1d6071f9ee101bc41e5b4c75f (new stock e511a4dbb32669282e14838ec012e2e0)

$ cd ../pubadmin-cli
$ node index.js stats
┌─────────────┬────────────┬─────────────────┬────────────────┬───────────────────────┐
│             │ Total slag │          Reused │      Discarded │           Price (€/t) │
│             │          t │           t [%] │          t [%] │        Avg [Min, Max] │
├─────────────┼────────────┼─────────────────┼────────────────┼───────────────────────┤
│ sidenor.com │     17.375 │ 3.763 [21.66 %] │ 1.302 [7.49 %] │ 18.13 [49.74, 522.61] │
└─────────────┴────────────┴─────────────────┴────────────────┴───────────────────────┘

┌─────────────────────┬────────────┬─────────────────────────┐
│                     │ Total slag │             Price (€/t) │
│                     │          t │          Avg [Min, Max] │
├─────────────────────┼────────────┼─────────────────────────┤
│ cement-company1.com │      0.667 │ 241.38 [121.79, 522.61] │
├─────────────────────┼────────────┼─────────────────────────┤
│ cement-company2.com │      3.096 │    49.74 [49.74, 49.74] │
└─────────────────────┴────────────┴─────────────────────────┘


# Or to generate/simulate a complete cycle:
$ cd ../batch-sim
$ node index.js simulate
```
