// COPYRIGHT: FUNDACIÓN TECNALIA RESEARCH & INNOVATION, 2022.

const faker = require("@faker-js/faker")
const { Option } = require("commander")

const { createCLIApp, HypercogApiClient } = require("@hypercog/utils")
const {
  createAsset,
  editComposition,
  sendToCone,
  sendToStock,
  acceptBid,
  discardStock
} = require("@hypercog/sidenor-cli")

const { bidAsset } = require("@hypercog/cement-cli")

const signInAs = async (apiClient, userMail, password) => {
  const [username, organization] = userMail.split("@")

  const okLogin = await apiClient.signIn(username, password, organization)
  if (!okLogin) {
    console.error("Unauthorized login")
    return
  }
}

const createAssetAndSendToCone = async (apiClient, name) => {
  const assetId = await createAsset(apiClient, name)
  await editComposition(apiClient, {
    assetId,
    caoPercentage: faker.datatype.number({ min: 40, max: 70 })
  })
  return sendToCone(apiClient, { assetId })
}

const simulateCycle = async (arg1, cmd) => {
  const { api, network, channel, chaincode, password, ...otherArgs } =
    cmd.parent.opts()

  const apiClient = new HypercogApiClient(api, network, channel, chaincode)

  await signInAs(apiClient, otherArgs.sidenorUser, password)

  let stockId
  for (let simId of [1, 2, 3]) {
    const batchId = await createAssetAndSendToCone(
      apiClient,
      `simulated asset ${simId}`
    )
    let mergedStock = await sendToStock(apiClient, {
      assetId: batchId,
      // The first time the user should select the stock as it is not provided
      stockId
    })
    stockId = mergedStock.id
  }

  const selectedStockId = await discardStock(apiClient, { assetId: stockId })
  const selectedStock = await apiClient.getAsset(selectedStockId)

  await signInAs(apiClient, otherArgs.cement1User, password)
  await bidAsset(apiClient, {
    assetId: selectedStockId,
    quantity: faker.datatype.number({ min: 200, max: selectedStock.quantity }),
    price: faker.datatype.number({ min: 50, max: 150 })
  })

  await signInAs(apiClient, otherArgs.cement2User, password)
  await bidAsset(apiClient, {
    assetId: selectedStockId,
    quantity: faker.datatype.number({ min: 100, max: selectedStock.quantity }),
    price: faker.datatype.number({ min: 25, max: 200 })
  })

  await signInAs(apiClient, otherArgs.sidenorUser, password)
  await acceptBid(apiClient, { assetId: selectedStockId })
}

const program = createCLIApp()
  .addOption(
    new Option(
      "-su --sidenorUser <value>",
      "User who will operate with blockchain as a steel manufacturer"
    ).env("SIDENOR_USER_ID")
  )
  .addOption(
    new Option(
      "-cu1 --cement1User <value>",
      "User who will operate with blockchain as a cement company 1"
    ).env("CEMENT1_USER_ID")
  )
  .addOption(
    new Option(
      "-cu2 --cement2User <value>",
      "User who will operate with blockchain as a cement company 2"
    ).env("CEMENT2_USER_ID")
  )

program.command("simulate").description("Simulate usage").action(simulateCycle)

program.parse(process.argv)
