// COPYRIGHT: FUNDACIÓN TECNALIA RESEARCH & INNOVATION, 2021.

const { createCLIApp, loginAndCallAfterwards } = require("@hypercog/utils")
const { table } = require("table")

const TABLE_CONFIG = {
  border: {
    topBody: `─`,
    topJoin: `┬`,
    topLeft: `┌`,
    topRight: `┐`,

    bottomBody: `─`,
    bottomJoin: `┴`,
    bottomLeft: `└`,
    bottomRight: `┘`,

    bodyLeft: `│`,
    bodyRight: `│`,
    bodyJoin: `│`,

    joinBody: `─`,
    joinLeft: `├`,
    joinRight: `┤`,
    joinJoin: `┼`
  },
  columns: [
    { alignment: "left" },
    { alignment: "right" },
    { alignment: "right" },
    { alignment: "right" },
    { alignment: "right" },
    { alignment: "right" },
    { alignment: "right" }
  ]
}

const humanizePercentage = value => {
  if (value.percentage === undefined) {
    return value.total
  }
  return `${value.total.toFixed(3)} [${(value.percentage * 100).toFixed(2)} %]`
}
const humanizePrice = value =>
  `${value.avg.toFixed(2)} [${value.min.toFixed(2)}, ${value.max.toFixed(2)}]`

const toSteelLine = stat => [
  stat.total.toFixed(3),
  humanizePercentage(stat.reused),
  humanizePercentage(stat.discarded),
  humanizePrice(stat.price)
]

const toCementLine = stat => [stat.total.toFixed(3), humanizePrice(stat.price)]

const printMainTable = ({ perSteelCompany = [] }) => {
  const header = [
    "",
    "Total slag\nt",
    "Reused\nt [%]",
    "Discarded\nt [%]",
    "Price (€/t)\n Avg [Min, Max]"
  ]
  let body = Object.entries(perSteelCompany).map(([org, val]) => [
    org,
    ...toSteelLine(val)
  ])
  if (body.length === 0) {
    body = [header.map(() => "-")]
  }
  console.log(table([header, ...body], TABLE_CONFIG))
}

const printCementOrgsTable = ({ perCementCompany = [] }) => {
  const header = ["", "Total slag\nt", "Price (€/t)\n Avg [Min, Max]"]
  let body = Object.entries(perCementCompany).map(([org, val]) => [
    org,
    ...toCementLine(val)
  ])
  if (body.length === 0) {
    body = [header.map(() => "-")]
  }
  console.log(table([header, ...body], TABLE_CONFIG))
}

const getStats = async apiClient => {
  const stats = await apiClient.getStats()

  printMainTable(stats)
  printCementOrgsTable(stats)
}

const program = createCLIApp()

program
  .command("stats")
  .description("Get stats for public administration")
  // get max, get min
  .action(loginAndCallAfterwards(getStats))

program.parse(process.argv)
