// COPYRIGHT: FUNDACIÓN TECNALIA RESEARCH & INNOVATION, 2021.

const { createCLIApp, loginAndCallAfterwards } = require("@hypercog/utils")

const {
  createAsset,
  editComposition,
  sendToCone,
  sendToStock,
  acceptBid,
  rejectBid,
  discardStock
} = require("./lib")

const program = createCLIApp()

program
  .command("register")
  .description("Initial registration of the slag")
  .option("--asset-name <value>", "Slag name")
  .action(loginAndCallAfterwards(createAsset))

program
  .command("composition")
  .description("Provide a slag composition measure")
  .option(
    "--asset-id [value]",
    "Identifier of the slag whose composition has been measured"
  )
  .option("--cao-percentage [value]", "CaO percentage in the slag")
  .action(loginAndCallAfterwards(editComposition))

program
  .command("to-cone")
  .description("Send slag to cone")
  .option("--asset-id [value]", "Identifier of the slag to be sent to the cone")
  .action(loginAndCallAfterwards(sendToCone))

program
  .command("to-stock")
  .description("Send slag from cone to stock")
  .option(
    "--asset-id [value]",
    "Identifier of the slag batch to be merged in the stock"
  )
  .action(loginAndCallAfterwards(sendToStock))

program
  .command("bid-accept")
  .description("Accept bid for slag stock")
  .option("--asset-id [value]", "Identifier of the slag stock")
  .option(
    "--bidder [value]",
    "Identifier of the bidder for the provided slag stock"
  )
  .action(loginAndCallAfterwards(acceptBid))

program
  .command("bid-reject")
  .description("Reject bid for slag stock")
  .option("--asset-id [value]", "Identifier of the slag stock")
  .option(
    "--bidder [value]",
    "Identifier of the bidder for the provided slag stock"
  )
  .action(loginAndCallAfterwards(rejectBid))

program
  .command("discard-stock")
  .description("Discard part of a slag stock sending it to the landfill")
  .option("--asset-id [value]", "Identifier of the slag stock")
  .option(
    "--quantity [value]",
    "Quantity of the slag stock to discard (i.e., to be sent to the landfill)"
  )
  .action(loginAndCallAfterwards(discardStock))

program.parse(process.argv)
