// COPYRIGHT: FUNDACIÓN TECNALIA RESEARCH & INNOVATION, 2021.

const TraceblockApiClient = require("@traceblock/api-client")

class HypercogApiClient extends TraceblockApiClient {
  constructor(endpoint, network, channel, chaincode) {
    super(endpoint, network, channel, chaincode)
  }

  getStats() {
    return this._queryExtractPayload("hypercog-stats")
  }

  getBiddableAssets() {
    return this._queryExtractPayload("hypercog-list-bid-assets")
  }

  bidForAsset(id, quantity, price) {
    return this._invoke("hypercog-bid-asset", {
      body: {
        id,
        bid: {
          quantity,
          price
        }
      }
    })
  }

  acceptBid(id, bidder) {
    return this._invoke("hypercog-accept-asset", {
      body: { id, bidder }
    })
  }

  rejectBid(id, bidder) {
    return this._invoke("hypercog-reject-asset", {
      body: { id, bidder }
    })
  }

  /**
   * Archives an asset (overrides original definition).
   *
   * @param {string} id Asset identifier.
   * @param {number} quantity Magnitude measured in the units specified in the associated asset definition.
   */
  async deleteAsset(id, quantity) {
    const { payload } = await this._invoke("asset-archive", {
      body: { id, quantity }
    })
    return payload
  }

  Bid(id, bidder) {
    return this._invoke("asset-archive", {
      body: { id, bidder }
    })
  }
}

module.exports = HypercogApiClient
