/**
 * acl.go
 *
 * COPYRIGHT: FUNDACIÓN TECNALIA RESEARCH & INNOVATION, 2021.
 */

package bid

import (
	"errors"

	"git.code.tecnalia.com/blockchain/hypercog/constants"
	"git.code.tecnalia.com/ledgerbuilder/sdk/core/api"
	"git.code.tecnalia.com/ledgerbuilder/sdk/core/fabric/protos"
	"git.code.tecnalia.com/ledgerbuilder/sdk/shared"
)

var (
	errNotSidenorMSP = errors.New("the asset does not belong to Sidenor")
)

func (c BidController) OwnedBySidenor(trigger shared.TriggerFunction) shared.TriggerFunction {
	return func(stub shared.LedgerBuildrStubInterface, requestAsset shared.LedgerBuildrAsset) protos.Response {
		const fnName = "ACL:OwnedBySidenor"

		storedAsset, err := c.readAsset(stub, requestAsset)
		if err != nil {
			return api.NewApiResponsePtr(fnName, err, nil).SendResponse()
		}

		if storedAsset.Owner.Org != constants.SidenorOrg  {
			return api.NewApiResponsePtr(fnName, errNotSidenorMSP, nil).SendResponse()
		}

		return trigger(stub, requestAsset)
	}
}