/**
 * bid_decision_input.go
 *
 * COPYRIGHT: FUNDACIÓN TECNALIA RESEARCH & INNOVATION, 2021.
 */

package bid

import (
	"git.code.tecnalia.com/ledgerbuilder/sdk/core/model/io"
	"git.code.tecnalia.com/ledgerbuilder/sdk/shared"
	errs "git.code.tecnalia.com/traceblock/sdk/constants"
)

type BidDecisionParams struct {
	shared.LedgerBuildrAsset
	AssetId     string `json:"id"`
	Bidder		string `json:"bidder"`
}

func (p *BidDecisionParams) GetID() string {
	return p.AssetId
}

func (p *BidDecisionParams) Get(key string) (interface{}, bool) {
	return nil, false
}

func (p *BidDecisionParams) SetID(id string) {
	p.AssetId = id
}

func (p *BidDecisionParams) StubBytes() []byte {
	return []byte{}
}

func (p *BidDecisionParams) LedgerBytes() []byte {
	return nil
}

func (p *BidDecisionParams) ReadValidation() bool {
	return false
}

// set write validations to false to avoid ledger persistency
func (p *BidDecisionParams) WriteValidation() bool {
	return false
}

func (p *BidDecisionParams) StubReader(stub shared.LedgerBuildrStubInterface) (shared.LedgerBuildrAsset, error) {
	if stub != nil {
		parseErr := io.NewJSONSerializer().LoadFromByteArray(&p, stub.GetPayload())
		return p, parseErr
	}
	return nil, errs.StubReader
}

func (p *BidDecisionParams) LedgerReader(data []byte) (shared.LedgerBuildrAsset, error) {
	if data != nil {
		parseErr := io.NewJSONSerializer().LoadFromByteArray(&p, data)
		return p, parseErr
	}
	return nil, errs.LedgerReader
}

func NewBidDecisionParams() shared.LedgerBuildrAsset {
	return new(BidDecisionParams)
}
