/**
 * bid_input.go
 *
 * COPYRIGHT: FUNDACIÓN TECNALIA RESEARCH & INNOVATION, 2021.
 */

package bid

import (
	"git.code.tecnalia.com/ledgerbuilder/sdk/core/model/io"
	"git.code.tecnalia.com/ledgerbuilder/sdk/shared"
	errs "git.code.tecnalia.com/traceblock/sdk/constants"
)

type BidParams struct {
	shared.LedgerBuildrAsset
	AssetId     string `json:"id"`
	Bid struct {
		Quantity    uint32 `json:"quantity"`
		Price   	float32 `json:"price"`
	} `json:"bid"`
}

func (p *BidParams) GetID() string {
	return p.AssetId
}

func (p *BidParams) Get(key string) (interface{}, bool) {
	return nil, false
}

func (p *BidParams) SetID(id string) {
	p.AssetId = id
}

func (p *BidParams) StubBytes() []byte {
	return []byte{}
}

func (p *BidParams) LedgerBytes() []byte {
	return nil
}

func (p *BidParams) ReadValidation() bool {
	return false
}

// set write validations to false to avoid ledger persistency
func (p *BidParams) WriteValidation() bool {
	return false
}

func (p *BidParams) StubReader(stub shared.LedgerBuildrStubInterface) (shared.LedgerBuildrAsset, error) {
	if stub != nil {
		parseErr := io.NewJSONSerializer().LoadFromByteArray(&p, stub.GetPayload())
		return p, parseErr
	}
	return nil, errs.StubReader
}

func (p *BidParams) LedgerReader(data []byte) (shared.LedgerBuildrAsset, error) {
	if data != nil {
		parseErr := io.NewJSONSerializer().LoadFromByteArray(&p, data)
		return p, parseErr
	}
	return nil, errs.LedgerReader
}

func NewBidParams() shared.LedgerBuildrAsset {
	return new(BidParams)
}
