/**
 * input.go
 *
 * COPYRIGHT: FUNDACIÓN TECNALIA RESEARCH & INNOVATION, 2022.
 */

package discard

import (
	"git.code.tecnalia.com/ledgerbuilder/sdk/core/model/io"
	"git.code.tecnalia.com/ledgerbuilder/sdk/shared"
	errs "git.code.tecnalia.com/traceblock/sdk/constants"
)

type DiscardParams struct {
	shared.LedgerBuildrAsset
	AssetId     string `json:"id"`
	Quantity    uint32 `json:"quantity,omitempty"`
}

func (p *DiscardParams) GetID() string {
	return p.AssetId
}

func (p *DiscardParams) Get(key string) (interface{}, bool) {
	return nil, false
}

func (p *DiscardParams) SetID(id string) {
	p.AssetId = id
}

func (p *DiscardParams) StubBytes() []byte {
	return []byte{}
}

func (p *DiscardParams) LedgerBytes() []byte {
	return nil
}

func (p *DiscardParams) ReadValidation() bool {
	return false
}

// set write validations to false to avoid ledger persistency
func (p *DiscardParams) WriteValidation() bool {
	return false
}

func (p *DiscardParams) StubReader(stub shared.LedgerBuildrStubInterface) (shared.LedgerBuildrAsset, error) {
	if stub != nil {
		parseErr := io.NewJSONSerializer().LoadFromByteArray(&p, stub.GetPayload())
		return p, parseErr
	}
	return nil, errs.StubReader
}

func (p *DiscardParams) LedgerReader(data []byte) (shared.LedgerBuildrAsset, error) {
	if data != nil {
		parseErr := io.NewJSONSerializer().LoadFromByteArray(&p, data)
		return p, parseErr
	}
	return nil, errs.LedgerReader
}

func NewDiscardParams() shared.LedgerBuildrAsset {
	return new(DiscardParams)
}
