/**
 * stats_controller.go
 *
 * COPYRIGHT: FUNDACIÓN TECNALIA RESEARCH & INNOVATION, 2022.
 */

package stats

import (
	"git.code.tecnalia.com/blockchain/hypercog/model/stats"
	"git.code.tecnalia.com/ledgerbuilder/sdk/core/api"
	"git.code.tecnalia.com/ledgerbuilder/sdk/core/fabric/protos"
	"git.code.tecnalia.com/ledgerbuilder/sdk/shared"
)


type StatsResult struct {
	PerSteelCompany map[string]stats.SteelStats `json:"perSteelCompany,omitempty"`
	PerCementCompany map[string]stats.CementStats `json:"perCementCompany,omitempty"`
}

func GetStatsOperation(stub shared.LedgerBuildrStubInterface, request shared.LedgerBuildrAsset) protos.Response {
	fnName := "GetStats"

	ret := new(StatsResult)

	orgs, err := getSteelOrgList(stub)
	if err != nil {
		return api.NewApiResponsePtr(fnName, err, nil).SendResponse()
	}

	if len(*orgs) > 0 {
		ret.PerSteelCompany = make(map[string]stats.SteelStats)
	}

	for _, org := range *orgs {
		orgStat, err := getSteelStats(stub, org)
		if err != nil {
			return api.NewApiResponsePtr(fnName, err, nil).SendResponse()
		}
		ret.PerSteelCompany[org] = *orgStat.RefineStats()
    }


	orgs, err = getCementOrgList(stub)
	if err != nil {
		return api.NewApiResponsePtr(fnName, err, nil).SendResponse()
	}

	if len(*orgs) > 0 {
		ret.PerCementCompany = make(map[string]stats.CementStats)
	}

	for _, org := range *orgs {
		orgStat, err := getCementStats(stub, org)
		if err != nil {
			return api.NewApiResponsePtr(fnName, err, nil).SendResponse()
		}
		ret.PerCementCompany[org] = *orgStat.RefineStats()
    }

	return api.NewAPIGenericResponsePtr(fnName, nil, ret).SendResponse()
}

func ResetStats(stub shared.LedgerBuildrStubInterface, request shared.LedgerBuildrAsset) protos.Response {
	err := resetStats(stub)
	return api.NewAPIGenericResponsePtr("ResetStats", err, nil).SendResponse()
}
