/**
 * acl.go
 *
 * COPYRIGHT: FUNDACIÓN TECNALIA RESEARCH & INNOVATION, 2021.
 */

package middleware

import (
	"errors"

	"git.code.tecnalia.com/blockchain/hypercog/constants"
	"git.code.tecnalia.com/ledgerbuilder/sdk/shared"
)

var (
	RejectIfNotSidenor = shared.NewMiddlewareFunction("reject-not-sidenor", rejectIfNotSidenor)
	RejectIfNotCementCompany = shared.NewMiddlewareFunction("reject-not-cement-company", rejectIfNotCementCompany)
	RejectIfNotPublicAdmin = shared.NewMiddlewareFunction("reject-not-public-admin", rejectIfNotPublicAdmin)
	errInvalidOrg = errors.New("user belongs to an invalid organization")
)

func rejectIfNotSidenor(stub shared.LedgerBuildrStubInterface, ctl shared.ControllerInterface, req shared.TXRequestInterface, request shared.LedgerBuildrAsset) (shared.LedgerBuildrAsset, error) {
	mspId := stub.GetMSPId()

	if (mspId == constants.SidenorMsp) {
		return request, nil
	}
	
	return nil, errInvalidOrg
}

func rejectIfNotCementCompany(stub shared.LedgerBuildrStubInterface, ctl shared.ControllerInterface, req shared.TXRequestInterface, request shared.LedgerBuildrAsset) (shared.LedgerBuildrAsset, error) {
	mspId := stub.GetMSPId()

	if (mspId == constants.Cement1Msp || mspId == constants.Cement2Msp) {
		return request, nil
	}
	
	return nil, errInvalidOrg
}

func rejectIfNotPublicAdmin(stub shared.LedgerBuildrStubInterface, ctl shared.ControllerInterface, req shared.TXRequestInterface, request shared.LedgerBuildrAsset) (shared.LedgerBuildrAsset, error) {
	mspId := stub.GetMSPId()

	if (mspId == constants.PublicAdminMsp) {
		return request, nil
	}
	
	return nil, errInvalidOrg
}