/**
 * selector.go
 *
 * COPYRIGHT: FUNDACIÓN TECNALIA RESEARCH & INNOVATION, 2021.
 */

package middleware

import (
	"git.code.tecnalia.com/blockchain/hypercog/constants"
	"git.code.tecnalia.com/ledgerbuilder/sdk/core/model/query"
	"git.code.tecnalia.com/ledgerbuilder/sdk/shared"
	"git.code.tecnalia.com/traceblock/sdk/middleware"
	"git.code.tecnalia.com/traceblock/sdk/model"
)

var (
	InjectMspConstraint	 = shared.NewMiddlewareFunction("inject-selector-msp", addMspConstraint)
	InjectOrgConstraint	 = shared.NewMiddlewareFunction("inject-selector-org", addOrgConstraint)
	InjectStockedAssetConstraint = shared.NewMiddlewareFunction("inject-stocked-asset-query", addStockedStatusConstraint)
	InjectSidenorOrgConstraint = shared.NewMiddlewareFunction("inject-sidenor-org", addSidenorOrgConstraint)
)

func addMspConstraint(stub shared.LedgerBuildrStubInterface, ctl shared.ControllerInterface, req shared.TXRequestInterface, request shared.LedgerBuildrAsset) (shared.LedgerBuildrAsset, error) {
	mspId := stub.GetMSPId()

	if (mspId == constants.PublicAdminMsp) {
		// If public administration => do not alter the query (full-access)
		return request, nil
	}

	// "sidenor-com"
	return middleware.AlterSelector(request, "selector.owner.msp", mspId)
}

func addOrgConstraint(stub shared.LedgerBuildrStubInterface, ctl shared.ControllerInterface, req shared.TXRequestInterface, request shared.LedgerBuildrAsset) (shared.LedgerBuildrAsset, error) {
	mspId := stub.GetMSPId()

	if (mspId == constants.PublicAdminMsp) {
		// If public administration => do not alter the query (full-access)
		return request, nil
	}

	org, err := model.GetOrganization(stub)
	if err != nil {
		return nil, err
	}

	return middleware.AlterSelector(request, "selector.owner.org", org)
}

func addStockedStatusConstraint(stub shared.LedgerBuildrStubInterface, ctl shared.ControllerInterface, req shared.TXRequestInterface, request shared.LedgerBuildrAsset) (shared.LedgerBuildrAsset, error) {
	return middleware.AlterSelector(
		query.NewQueryStringWithContent("{}"),
		"selector.fields.status",
		"stocked",
	)
}

func addSidenorOrgConstraint(stub shared.LedgerBuildrStubInterface, ctl shared.ControllerInterface, req shared.TXRequestInterface, request shared.LedgerBuildrAsset) (shared.LedgerBuildrAsset, error) {
	// If more than one:
	// middleware.AlterSelector(request, "selector.owner.msp.$in", fmt.Sprintf("[\"%s\",\"%s\"]", "msp1", "sidenor-com"))
	return middleware.AlterSelector(request, "selector.owner.org", constants.SidenorOrg)
}