/**
 * status_test.go
 *
 * COPYRIGHT: FUNDACIÓN TECNALIA RESEARCH & INNOVATION, 2021.
 */

package middleware

import (
	"testing"

	"git.code.tecnalia.com/traceblock/sdk/model"
)

// go test -v middleware/*

func TestCheckStatus(t *testing.T) {
	t.Run("valid", testCheckStatusValid)
	t.Run("unset", testCheckStatusUnset)
	t.Run("invalid", testCheckStatusInvalid)
}

func testCheckStatusValid(t *testing.T) {
	traceableAsset :=  model.NewTraceableAsset()
	traceableAsset.ArbitraryDataFields["status"] = "demolished"

	_, err := _rejectIfInvalidStatus(nil, nil, nil, traceableAsset)
	if err != nil {
		t.Errorf("unexpected error %v", err)
	}
}

func testCheckStatusUnset(t *testing.T) {
	traceableAsset :=  model.NewTraceableAsset()

	_, err := _rejectIfUnsetOrInvalidStatus(nil, nil, nil, traceableAsset)
	if err == nil {
		t.Errorf("expecting error")
	}

	_, err = _rejectIfInvalidStatus(nil, nil, nil, traceableAsset)
	if err != nil {
		t.Errorf("unexpected error %v", err)
	}
}

func testCheckStatusInvalid(t *testing.T) {
	traceableAsset :=  model.NewTraceableAsset()
	traceableAsset.ArbitraryDataFields["status"] = "unlikely"

	_, err := _rejectIfInvalidStatus(nil, nil, nil, traceableAsset)
	if err == nil {
		t.Errorf("expecting error %v", err)
	}
}