/**
 * cement.go
 *
 * COPYRIGHT: FUNDACIÓN TECNALIA RESEARCH & INNOVATION, 2022.
 */

package stats

// Refined stats which will be returned
type CementStats struct {
	TotalSlag float64 `json:"total"` // in tons
	SoldBatch float64 `json:"sold"` // in t/sold batch
	Price SummaryMetric `json:"price"` // in t/€
}

// Raw stored stats (per cement company)
type RawCementOrgStats struct {
	RawStats
}

func (raw *RawCementOrgStats) UpgradeSale(quantity uint32, price float32, units string) {
	soldBatch := toTons(quantity, units)
	raw.TotalSlag += soldBatch
	raw.TotalPrice += float64(price)
	raw.SoldBatches += 1

	convertedPrice := float64(price) / soldBatch
	if convertedPrice < raw.MinPrice {
		raw.MinPrice = convertedPrice
	}

	if raw.MaxPrice < convertedPrice {
		raw.MaxPrice = convertedPrice
	}
}

func (raw *RawCementOrgStats) RefineStats() (*CementStats) {
	ret := new(CementStats)
	ret.TotalSlag = raw.TotalSlag

	ret.SoldBatch = ret.TotalSlag / float64(raw.SoldBatches)

	ret.Price.Minimum = raw.MinPrice
	ret.Price.Maximum = raw.MaxPrice
	if raw.TotalSlag > 0 {
		ret.Price.Average = raw.TotalPrice / raw.TotalSlag
	}

	return ret
}
