# HyperCog deployment

The following branch contains a deployment with multiple organizations participating in the same network and channel.
For a different setup, check other branches in this repository.

## Usage

The following sections will describe how to deploy and configure the network, the API and the Dashboard.

### 0. Prerequisites

In the machine where you want to deploy this, you must have the following software installed:

- [Golang](https://golang.org/). Make sure a [recent version](https://golang.org/dl/) is [installed](https://golang.org/doc/install).
- [Docker](https://www.docker.com/).
- [Docker-compose](https://docs.docker.com/compose/).
- [Minifabric](https://github.com/hyperledger-labs/minifabric#getting-started).

### 1. Blockchain network

Go to _network_ subfolder.

#### Bringing the network up

You can boot the network up by executing:

```bash
./up.sh
```

If you want to customize something, all the relevant _Hyperledger Fabric_ information is in _network/config.sh_.

#### Deploying new chaincode

1. Edit **CHAINCODE_PATH** in _network/config.sh_ to point to the [chaincode](https://git.code.tecnalia.com/traceblock/sdk).
1. Run `./ccup.sh`

**Note**: The chaincode version will be automatically bumped in each run.
If you want to manually adjust it, edit _version.sh_.

#### Stopping the network

```bash
minifab down
```

#### Cleaning previous network configuration

```bash
minifab cleanup
```

### 2. API and Dashboard

First, configure **Tecnalia's Docker registry** following this procedure:

1. Create _~/.docker/config.json_ if it does not exist.
1. Log into our [artifactory](https://blockchain-docker.artifact.tecnalia.com)
1. Go to _Artifactory > Artifacts_
1. Search for _blockchain-docker_ and select it
1. Click on the _Set Me Up_ button.
1. Type your password in the _Configure_ section's text field and click in the _lock icon_.
1. Copy the snippet shown in the same _Configure_ section and paste it in your _~/.docker/config.json_.
1. Edit the repository URL to make sure that _https://blockchain-docker.artifact.tecnalia.com_ is used.
   You should have a json which looks like the following one.

```json
{
	"auths": {
		"https://blockchain-docker.artifact.tecnalia.com": {
			"auth": "***",
			"email": "user@tecnalia.com"
		}
	}
}
```

Once the Blockchain network has been booted up,
go to _apps_ subfolder and execute:

```bash
./setup.sh
```

From that point on, you can bring the API and the dashboard up with:

```bash
docker-compose up -d
```

To tear API and dashboard down execute:

```bash
docker-compose down
```
